Skip to main contentCrate ferroalloc_probe
Source - AllocEvent
- An allocation event with the source location already resolved by the probe.
Resolving at the probe side avoids ASLR/DWARF mismatch issues on macOS.
- FerroAllocator
- Drop-in global allocator that wraps the system allocator and records every
heap operation into
EVENT_QUEUE for streaming to the ferroalloc analyzer.
- EVENT_QUEUE
- set_sample_rate
- Set the sampling rate. Only 1 in every
n allocations will be recorded. - start_flush_thread
- Starts the background flush thread that streams allocation events to the analyzer.